<?php

/**
 * @file
 * Creates a view and a menu link (hook_menu style).
 *
 * Creates a new View within the Commerce reports area where
 * people can see any errors that may have occurred during synchronization.
 */

/**
 * Implements hook_views_data().
 */
function ji_commerce_views_data_alter(&$data) {
  $data['commerce_order']['data'] = array(
    'title' => t('Data'),
    'help' => t('Provide serialized data of the order'),
    'field' => array('handler' => 'ji_commerce_handler_fied_data'),
    'filter' => array('handler' => 'views_handler_filter_string')
  );
}

/**
 * Implements hook_views_default_views().
 */
function ji_commerce_views_default_views() {
  $view = new view();
  $view->name = 'failed_order_sync';
  $view->description = '';
  $view->tag = 'commerce_reports';
  $view->base_table = 'commerce_order';
  $view->human_name = 'Failed QBO Order Sync';
  $view->core = 7;
  $view->api_version = '3.0';
  // Edit this to true to make a default view disabled initially.
  $view->disabled = FALSE;

  // Display: Master.
  $handler = $view->new_display('default', 'Master', 'default');
  $handler->display->display_options['title'] = 'QuickBooks orders sync status';
  $handler->display->display_options['use_more_always'] = FALSE;
  $handler->display->display_options['access']['type'] = 'none';
  $handler->display->display_options['cache']['type'] = 'none';
  $handler->display->display_options['query']['type'] = 'views_query';
  $handler->display->display_options['exposed_form']['type'] = 'basic';
  $handler->display->display_options['pager']['type'] = 'mini';
  $handler->display->display_options['pager']['options']['items_per_page'] = '15';
  $handler->display->display_options['pager']['options']['offset'] = '0';
  $handler->display->display_options['pager']['options']['id'] = '0';
  $handler->display->display_options['style_plugin'] = 'table';
  $handler->display->display_options['style_options']['columns'] = array(
    'order_number' => 'order_number',
    'status' => 'status',
    'created' => 'created',
    'data' => 'data',
    'data_1' => 'data_1',
    'data_2' => 'data_2',
  );
  $handler->display->display_options['style_options']['default'] = '-1';
  $handler->display->display_options['style_options']['info'] = array(
    'order_number' => array(
      'sortable' => 1,
      'default_sort_order' => 'asc',
      'align' => '',
      'separator' => '',
      'empty_column' => 0,
    ),
    'status' => array(
      'sortable' => 1,
      'default_sort_order' => 'asc',
      'align' => '',
      'separator' => '',
      'empty_column' => 0,
    ),
    'created' => array(
      'sortable' => 1,
      'default_sort_order' => 'asc',
      'align' => '',
      'separator' => '',
      'empty_column' => 0,
    ),
    'data' => array(
      'align' => '',
      'separator' => '',
      'empty_column' => 0,
    ),
    'data_1' => array(
      'align' => '',
      'separator' => '',
      'empty_column' => 0,
    ),
    'data_2' => array(
      'align' => '',
      'separator' => '',
      'empty_column' => 0,
    ),
  );
  $handler->display->display_options['style_options']['empty_table'] = TRUE;
  // No results behavior: Global: Text area.
  $handler->display->display_options['empty']['area']['id'] = 'area';
  $handler->display->display_options['empty']['area']['table'] = 'views';
  $handler->display->display_options['empty']['area']['field'] = 'area';
  $handler->display->display_options['empty']['area']['label'] = 'No issues encountered';
  $handler->display->display_options['empty']['area']['empty'] = TRUE;
  $handler->display->display_options['empty']['area']['content'] = 'No errors to report.';
  $handler->display->display_options['empty']['area']['format'] = 'full_html';
  // Field: Commerce Order: Order number.
  $handler->display->display_options['fields']['order_number']['id'] = 'order_number';
  $handler->display->display_options['fields']['order_number']['table'] = 'commerce_order';
  $handler->display->display_options['fields']['order_number']['field'] = 'order_number';
  $handler->display->display_options['fields']['order_number']['link_to_order'] = 'admin';
  // Field: Commerce Order: Order status.
  $handler->display->display_options['fields']['status']['id'] = 'status';
  $handler->display->display_options['fields']['status']['table'] = 'commerce_order';
  $handler->display->display_options['fields']['status']['field'] = 'status';
  // Field: Commerce Order: Created date.
  $handler->display->display_options['fields']['created']['id'] = 'created';
  $handler->display->display_options['fields']['created']['table'] = 'commerce_order';
  $handler->display->display_options['fields']['created']['field'] = 'created';
  $handler->display->display_options['fields']['created']['date_format'] = 'short';
  $handler->display->display_options['fields']['created']['second_date_format'] = 'long';
  $handler->display->display_options['fields']['created']['format_date_sql'] = 0;
  // Field: Commerce Order: Data.
  $handler->display->display_options['fields']['data']['id'] = 'data';
  $handler->display->display_options['fields']['data']['table'] = 'commerce_order';
  $handler->display->display_options['fields']['data']['field'] = 'data';
  $handler->display->display_options['fields']['data']['label'] = 'QBO Invoice ID';
  $handler->display->display_options['fields']['data']['exclude'] = TRUE;
  $handler->display->display_options['fields']['data']['format'] = 'key';
  $handler->display->display_options['fields']['data']['key'] = 'qbo_invoice_id';
  // Field: Commerce Order: Data.
  $handler->display->display_options['fields']['data_1']['id'] = 'data_1';
  $handler->display->display_options['fields']['data_1']['table'] = 'commerce_order';
  $handler->display->display_options['fields']['data_1']['field'] = 'data';
  $handler->display->display_options['fields']['data_1']['exclude'] = TRUE;
  $handler->display->display_options['fields']['data_1']['format'] = 'key';
  $handler->display->display_options['fields']['data_1']['key'] = 'last_cart_refresh';
  // Field: Commerce Order: Data.
  $handler->display->display_options['fields']['data_2']['id'] = 'data_2';
  $handler->display->display_options['fields']['data_2']['table'] = 'commerce_order';
  $handler->display->display_options['fields']['data_2']['field'] = 'data';
  $handler->display->display_options['fields']['data_2']['exclude'] = TRUE;
  $handler->display->display_options['fields']['data_2']['key'] = 'commerce_payment_order_paid_in_full_invoked';
  // Filter criterion: Commerce Order: Data.
  $handler->display->display_options['filters']['data']['id'] = 'data';
  $handler->display->display_options['filters']['data']['table'] = 'commerce_order';
  $handler->display->display_options['filters']['data']['field'] = 'data';
  $handler->display->display_options['filters']['data']['operator'] = 'contains';
  $handler->display->display_options['filters']['data']['value'] = 'qbo_error';

  // Display: Block.
  $handler = $view->new_display('block', 'Block', 'block');
  $handler->display->display_options['block_description'] = 'Orders not synced';

  // Display: Page.
  $handler = $view->new_display('page', 'Page', 'page_1');
  $handler->display->display_options['defaults']['fields'] = FALSE;
  // Field: Commerce Order: Order number.
  $handler->display->display_options['fields']['order_number']['id'] = 'order_number';
  $handler->display->display_options['fields']['order_number']['table'] = 'commerce_order';
  $handler->display->display_options['fields']['order_number']['field'] = 'order_number';
  $handler->display->display_options['fields']['order_number']['link_to_order'] = 'admin';
  // Field: Commerce Order: Order status.
  $handler->display->display_options['fields']['status']['id'] = 'status';
  $handler->display->display_options['fields']['status']['table'] = 'commerce_order';
  $handler->display->display_options['fields']['status']['field'] = 'status';
  // Field: Commerce Order: Created date.
  $handler->display->display_options['fields']['created']['id'] = 'created';
  $handler->display->display_options['fields']['created']['table'] = 'commerce_order';
  $handler->display->display_options['fields']['created']['field'] = 'created';
  $handler->display->display_options['fields']['created']['date_format'] = 'short';
  $handler->display->display_options['fields']['created']['second_date_format'] = 'long';
  $handler->display->display_options['fields']['created']['format_date_sql'] = 0;
  // Field: Commerce Order: Data.
  $handler->display->display_options['fields']['data']['id'] = 'data';
  $handler->display->display_options['fields']['data']['table'] = 'commerce_order';
  $handler->display->display_options['fields']['data']['field'] = 'data';
  $handler->display->display_options['fields']['data']['label'] = 'QBO Invoice ID';
  $handler->display->display_options['fields']['data']['format'] = 'key';
  $handler->display->display_options['fields']['data']['key'] = 'qbo_invoice_id';
  // Field: Commerce Order: Data.
  $handler->display->display_options['fields']['data_3']['id'] = 'data_3';
  $handler->display->display_options['fields']['data_3']['table'] = 'commerce_order';
  $handler->display->display_options['fields']['data_3']['field'] = 'data';
  $handler->display->display_options['fields']['data_3']['label'] = 'Error Message';
  $handler->display->display_options['fields']['data_3']['format'] = 'key';
  $handler->display->display_options['fields']['data_3']['key'] = 'qbo_error';
  // Field: Commerce Order: Data.
  $handler->display->display_options['fields']['data_1']['id'] = 'data_1';
  $handler->display->display_options['fields']['data_1']['table'] = 'commerce_order';
  $handler->display->display_options['fields']['data_1']['field'] = 'data';
  $handler->display->display_options['fields']['data_1']['exclude'] = TRUE;
  $handler->display->display_options['fields']['data_1']['key'] = 'last_cart_refresh';
  $handler->display->display_options['defaults']['filter_groups'] = FALSE;
  $handler->display->display_options['defaults']['filters'] = FALSE;
  // Filter criterion: Commerce Order: Order status.
  $handler->display->display_options['filters']['status']['id'] = 'status';
  $handler->display->display_options['filters']['status']['table'] = 'commerce_order';
  $handler->display->display_options['filters']['status']['field'] = 'status';
  $handler->display->display_options['filters']['status']['value'] = array(
    'completed' => 'completed',
  );
  $handler->display->display_options['filters']['status']['exposed'] = TRUE;
  $handler->display->display_options['filters']['status']['expose']['operator_id'] = 'status_op';
  $handler->display->display_options['filters']['status']['expose']['label'] = 'Order status';
  $handler->display->display_options['filters']['status']['expose']['operator'] = 'status_op';
  $handler->display->display_options['filters']['status']['expose']['identifier'] = 'status';
  $handler->display->display_options['filters']['status']['expose']['remember_roles'] = array(
    2 => '2',
    1 => 0,
    3 => 0,
  );
  $handler->display->display_options['path'] = 'admin/commerce/reports/qbo-sync-report';
  $handler->display->display_options['menu']['type'] = 'tab';
  $handler->display->display_options['menu']['title'] = 'QBO Sync Report';
  $handler->display->display_options['menu']['weight'] = '0';
  $handler->display->display_options['menu']['context'] = 0;
  $handler->display->display_options['menu']['context_only_inline'] = 0;

  $views[$view->name] = $view;
  return $views;
}
